Learn R Programming

Mega2R (version 1.1.0)

Mega2famSKATRC: execute the CRAN famSKAT_RC function on a subset of the gene transcripts

Description

If the gene argument is NULL, execute the famSKAT_RC function on the first gs gene transcripts (default is gs = 1:100). Update the envir$famSKATRC_results data frame with the results. Otherwise, gene is a string vector of genes to process. The special value '*' stands for all the known genes.

Usage

Mega2famSKATRC(gs = 1:100, genes = NULL, envir = ENV, ...)

Value

The data frame with the results is stored in the environment and named famSKATRC_results, viz. envir$famSKATRC_results

Arguments

gs

a subrange of the default transcripts (refRanges) over which to calculate the DOfamSKATRC function.

genes

a list of genes over which to calculate the DOfamSKATRC function. The value, "*", means use all the transcripts in the selected Bioconductor database. If genes is NULL, the gs range of the internal refRanges will be used.

envir

'environment' containing SQLite database and other globals.

...

extra arguments that are acceptable to famSKAT_RC. These are listed with the DOfamSKATRC function.

See Also

init_famSKATRC, DOfamSKATRC

Examples

Run this code
db = system.file("exdata", "seqsimm.db", package="Mega2R")
ENV = init_famSKATRC(db, verbose = FALSE)
ENV$verbose = FALSE
ENV$famSKATRC_results = ENV$famSKATRC_results[0, ]
Mega2famSKATRC(gs=50:60, envir=ENV, pheno=3)

# \donttest{
# donttestcheck: try this below if there is time
 Mega2famSKATRC(genes=c("CEP104"), envir=ENV, pheno=3 )
# }

ENV$famSKATRC_results

Run the code above in your browser using DataLab