Learn R Programming

Mega2R (version 1.0.2)

getgenotype_person: return the genotypes for all markers of a given person

Description

for selected person, expand genotype bit vector to an integer vector with one integer per marker. Then convert the integer vector to genotypes.

Usage

getgenotype_person(perid = 1, envir = ENV)

Arguments

perid

person/sample identifier

envir

an environment that contains all the data frames created from the SQLite database.

Value

None

Examples

Run this code
# NOT RUN {
# genotypes for all markers for n'th person in genotype table
getgenotype_person(1)

# genotypes for all markers for range of persons in genotype table
getgenotype_person(m:n)
# }

Run the code above in your browser using DataLab