Learn R Programming

Mega2R (version 1.0.7)

init_famSKATRC: load Mega2 SQLite database and perform initialization for famSKATRC usage

Description

This populates the R data frames with the specified Mega2 SQLite database. It initializes the fam(ily) table and makes sure the person entries are unique. Finally, it generates a kinship matrix from the family data. It also stores a weighting for the common and rare variant that may be used later if NULL is specified as a weight in Mega2famSKATRC. The common weighting is the function dbeta(maf, 1, 25). The rare weighting is the function dbeta(maf, 0.5, 0.5).

Usage

init_famSKATRC(db = NULL, verbose = FALSE, ALPHA = FALSE, ...)

Arguments

db

specifies the path of a Mega2 SQLite database containing study data.

verbose

TRUE indicates that diagnostic printouts should be enabled. This value is saved in the returned environment.

ALPHA

TRUE indicates that two runs of famSKAT_RC should be enabled. One with ALPHA numeric ID's and one with numeric IDs ... this is temporary. The default is FALSE.

...

fed to dbmega2_import(); should be bpPosMap= to select from the maps of base pairs, if the default is not desired.

Value

"environment" containing data frames from an SQLite database and some computed values.

See Also

Mega2famSKATRC

Examples

Run this code
# NOT RUN {
db = system.file("exdata", "seqsimm.db", package="Mega2R")
ENV = init_famSKATRC(db, verbose = FALSE)
ls(ENV)

# }

Run the code above in your browser using DataLab