Learn R Programming

Mega2R (version 1.1.0)

showMega2ENV: show Mega2R environment, viz. data frames and related info.

Description

Mega2R uses an environment to store the data frames when it reads SQLite database tables. This function shows the data frames and their sizes; it also shows the count of samples and markers in the database. Note: It is not necessary to provide an argument, if the environment is named ENV.

Usage

showMega2ENV(envir = ENV)

Value

None

Arguments

envir

an environment that contains all the data frames created from the SQLite database.

Examples

Run this code
db = system.file("exdata", "seqsimm.db", package="Mega2R")
ENV = read.Mega2DB(db)

showMega2ENV()

Run the code above in your browser using DataLab