powered by
for selected person, expand genotype bit vector to an integer vector with one integer per marker. Then convert the integer vector to genotypes.
getgenotype_person(perid = 1, envir = ENV)
person/sample identifier
an environment that contains all the data frames created from the SQLite database.
None
# NOT RUN { # genotypes for all markers for n'th person in genotype table getgenotype_person(1) # genotypes for all markers for range of persons in genotype table getgenotype_person(m:n) # }
Run the code above in your browser using DataLab