mk_markers_with_skip: make the derived "markers" data frame and store it in the environment.
Description
Create the markers data frame as a subset of the markers_table data frame. It contains 5
observations:
locus_link:
locus offset of this marker
locus_link_fill:
locus offset plus an accumulating fudge factor that jumps
with each new chromosome because the count of markers per chromosome is force to be
a multiple of 4. (This value corresponds to the offset of the marker in the
unified_genotype_table.)
MarkerName:
name of this marker
chromosome:
chromosome number of this marker
position:
base pair position of this marker (selected by bpPosMap[below])
Usage
mk_markers_with_skip(bpPosMap = 1, envir)
Arguments
bpPosMap
An integer that indicates the map (index) to use to fetch the
chromosome/position fields from the map_table data frame to merge with the marker_table.
envir
an environment that contains all the data frames created from the SQLite database.